%% Class for article in Acta Universitatis Matthiae Belii series Mathematics
%% Revision: $Id: aumbart.cls 1631 2013-05-29 09:12:01Z janci $
%% Document class `aumbart' is based on the style `amcjou' of
%% Ars Mathematica Contemporanea.
%% Author   : Jan Karabas
%%
%% (c) Copyright 2013- Matej Bel University 
%%
%% Licensed under the Educational Community License, Version 2.0 (the "License");
%% you may not use this file except in compliance with the License. You may obtain 
%% a copy of the License at
%%
%% http://www.osedu.org/licenses/ECL-2.0
%%
%% Unless required by applicable law or agreed to in writing, software distributed
%% under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
%% CONDITIONS OF ANY KIND, either express or implied. See the License for the
%% specific language governing permissions and limitations under the License.
%
\NeedsTeXFormat{LaTeX2e}[2011/06/27]
\ProvidesClass{aumbart}[2023/01/26 AUMBM style, version 2.1.1]

% draft version of the paper
\newif\if@draft
\@drafttrue         % true by default, if no other option is used
\newif\if@linenum
\@linenumtrue        % line numbers are active in draft only, now true!!!

% online version of the paper, false by default
\newif\if@online
\@onlinefalse

\newif\if@noabstract
\@noabstractfalse
\newif\if@hasabstract
\@hasabstractfalse

% set options for the package and load the base package
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\DeclareOption{draft}{\@drafttrue
		      \@linenumtrue
                     % \@onlinetrue
		     }
\DeclareOption{final}{\@draftfalse
		      \@linenumfalse
		     }
%\DeclareOption{online}{\@onlinetrue}

\DeclareOption{nonumber}{\@linenumfalse}

\ProcessOptions
\LoadClass[b5paper,twoside,10pt]{article}

\let\title\undefined
\let\author\undefined

% load Ams math packages
\RequirePackage{amsmath}
\RequirePackage{amsthm}
\RequirePackage{amsfonts}


% load font packages
%\RequirePackage[T1]{fontenc}
\RequirePackage[utf8]{inputenc}
\RequirePackage{lmodern}
\RequirePackage{soulutf8}

% load layout packages
\RequirePackage{geometry}
\geometry{paperwidth=176mm,paperheight=250mm}
\geometry{textwidth=135mm,textheight=210mm}
\geometry{outer=20mm}
\geometry{top=20mm}
\geometry{headsep=5mm,footskip=5mm}

\RequirePackage[hang,flushmargin]{footmisc}

% handle with numberings of lines, load lineno package
\if@linenum
\RequirePackage{lineno}
%\AtBeginDocument{%
%
\let\oldequation\equation%
\let\endoldequation\endequation%
\renewenvironment{equation}%
  {\linenomath\oldequation}{\endoldequation\endlinenomath}%
%
\expandafter\let\expandafter\oldequationstar\csname equation*\endcsname%
\expandafter\let\expandafter\endoldequationstar\csname endequation*\endcsname%
\renewenvironment{equation*}%
  {\linenomath\oldequationstar}{\endoldequationstar\endlinenomath}%
%
\let\oldalign\align%
\let\endoldalign\endalign%
\renewenvironment{align}%
  {\linenomath\oldalign}{\endoldalign\endlinenomath}%
%
\expandafter\let\expandafter\oldalignstar\csname align*\endcsname%
\expandafter\let\expandafter\endoldalignstar\csname endalign*\endcsname%
\renewenvironment{align*}%
  {\linenomath\oldalignstar}{\endoldalignstar\endlinenomath}%
%
\let\oldflalign\flalign%
\let\endoldflalign\endflalign%
\renewenvironment{flalign}%
  {\linenomath\oldflalign}{\endoldflalign\endlinenomath}%
%
\expandafter\let\expandafter\oldflalignstar\csname flalign*\endcsname%
\expandafter\let\expandafter\endoldflalignstar\csname endflalign*\endcsname%
\renewenvironment{flalign*}%
  {\linenomath\oldflalignstar}{\endoldflalignstar\endlinenomath}%
%
\let\oldalignat\alignat%
\let\endoldalignat\endalignat%
\renewenvironment{alignat}%
  {\linenomath\oldalignat}{\endoldalignat\endlinenomath}%
%
\expandafter\let\expandafter\oldalignatstar\csname alignat*\endcsname%
\expandafter\let\expandafter\endoldalignatstar\csname endalignat*\endcsname%
\renewenvironment{alignat*}%
  {\linenomath\oldalignatstar}{\endoldalignatstar\endlinenomath}%
%
\let\oldgather\gather%
\let\endoldgather\endgather%
\renewenvironment{gather}%
  {\linenomath\oldgather}{\endoldgather\endlinenomath}%
%
\expandafter\let\expandafter\oldgatherstar\csname gather*\endcsname%
\expandafter\let\expandafter\endoldgatherstar\csname endgather*\endcsname%
\renewenvironment{gather*}%
  {\linenomath\oldgatherstar}{\endoldgatherstar\endlinenomath}%
%
\let\oldmultline\multline%
\let\endoldmultline\endmultline%
\renewenvironment{multline}%
  {\linenomath\oldmultline}{\endoldmultline\endlinenomath}%
%
\expandafter\let\expandafter\oldmultlinestar\csname multline*\endcsname%
\expandafter\let\expandafter\endoldmultlinestar\csname endmultline*\endcsname%
\renewenvironment{multline*}%
  {\linenomath\oldmultlinestar}{\endoldmultlinestar\endlinenomath}%
%
%}
\fi

% package 'float' must be loaded before 'hyperref'

\RequirePackage{float}

% hyperref setup

\RequirePackage{xcolor}
\RequirePackage[hyperfootnotes=false, pagebackref=false]{hyperref}
\hypersetup{
    pdfdisplaydoctitle=true,
    colorlinks,
    linkcolor={green!50!black},
    citecolor={red!80!black},
    urlcolor={blue!80!black}
}

\if@draft
    \hypersetup{
      hyperfootnotes=true,
      pagebackref=true
    }
% \else
% % \usepackage{xcolor}
%     \hypersetup{
%       hyperfootnotes=false,
%       pagebackref=false
%     }
\fi
\RequirePackage{url}
\urlstyle{tt}


% fonts, sizes, and numbering setup
\renewcommand{\normalsize}{\fontsize{10}{12}\selectfont}
\numberwithin{equation}{section}


% macros
\newcount\@authorcount
\newcount\@footcount
\@authorcount=0
\@footcount=0
\def\@authors{}
\def\@firstauthor{}
\def\@authorlist{}
\def\@emails{}
\def\@journalname{Acta Universitatis Matthiae Belii,~series Mathematics}
\def\p@pertitle{}
\long\def\symbolfootnote[#1]#2{\begingroup%
\def\thefootnote{\fnsymbol{footnote}}\footnote[#1]{#2}\endgroup} 
\def\@journalnumber{00}
\def\@journalyear{20xx}
\def\@startpage{1}
\def\@endpage{*}
\def\@oddrunninghead{\if@linenum\nolinenumbers{}\fi{}Acta Univ.\ M.\ Belii,~ser. Math.\ \@journalnumber{} (\@journalyear),~\@startpage--\@endpage}
\def\@evenrunninghead{\if@linenum\nolinenumbers{}\fi{}\@authors}
\def\@lastrevdate{*}
\def\@receivedate{*}
\def\@acceptdate{*}
\def\@onlinedate{*}
\def\@communicated{*}
\def\@serial{*}
\def\@msca{*}
\def\@mscy{*}
\def\@keywords{*}

\newcommand{\journalnumber}[1]{\def\@journalnumber{#1}}
\newcommand{\journalyear}[1]{\def\@journalyear{#1}}
\newcommand{\journalpages}[2]{%
\def\@startpage{#1}
\def\@endpage{#2}
}
\newcommand{\oddrunninghead}[1]{\def\@oddrunninghead{#1}}
\newcommand{\evenrunninghead}[1]{\def\@evenrunninghead{#1}}

\newcommand{\submitdate}[1]{\def\@receivedate{#1}}
\newcommand{\acceptdate}[1]{\def\@acceptdate{#1}}
\newcommand{\lastrevdate}[1]{\def\@lastrevdate{#1}}
\newcommand{\onlinedate}[1]{\def\@onlinedate{#1}}
\newcommand{\communicated}[1]{\def\@communicated{#1}}
\newcommand{\serial}[1]{\def\@serial{ISBN #1}}



\newcommand{\footadvance}[1]{%
\global\advance\@footcount by #1
}


\newenvironment{frontmatter}{
    \thispagestyle{aptitle}
    \setcounter{page}{\@startpage}
    %
    \if@linenum
      \nolinenumbers
    \fi
    \if@draft
      \begin{center}
          {\small\sf\bfseries \@journalname{}}\\[-1.2mm]
  %        {\scriptsize \it Also available at {\tt http://actamath.savbb.sk}\\[-1.4mm]
          {\scriptsize \it Author's manuscript}%\\[-1.2mm]
      \end{center}
    \else
%     \if@online
%         \begin{center}
%             {\small\sf\bfseries \@journalname{}}\\[-0.9mm]
%             {\scriptsize\sf Issue \@journalyear,~\@startpage--\@endpage, ISSN 1338-7111}\\[-1.1mm]
%             {\scriptsize\it Online version, {\tt http://actamath.savbb.sk}}\\[-0.9mm]
% %        {\scriptsize \it }\\%\\[-1.2mm]
%         \end{center}
%     \else
      \begin{center}
          {\small\sf\bfseries \@journalname{}}\\[-0.9mm]
          {\scriptsize\sf Volume \@journalnumber{} (\@journalyear),~\@startpage--\@endpage, ISSN 1338-7111}\\[-1.1mm]%, {\if*\@serial ISBN 000-00-0000-000-0\else\@serial\fi}}\\[-1.1mm]
          {\scriptsize{\itshape Available at} \url{https://actamath.savbb.sk}}\\[-0.9mm]
  %        {\scriptsize \it }\\%\\[-1.2mm]
      \end{center}
    % \fi
    \fi
    %
    \if@linenum\global\linenumbers\fi
    \aftergroup\@afterindentfalse
    \aftergroup\@afterheading
    %
    
    \newcommand{\title}[2]{%
        \global\def\p@pertitle{##1}%
        \vskip 5mm
        \begin{center}
            \sf\LARGE\bfseries%
            ##1\if!##2!\else
                    \global\advance\@footcount by 1%
                    \symbolfootnote[\@footcount]{##2}
                \fi
        \end{center}%
        \vskip 5mm
    }

    \newcommand{\author}[4]{
        \advance\@authorcount by 1%
       %\xdef\@emails{\@emails\ifnum\@authorcount>1 , \fi {#3} (#1)}
        \xdef\@authorlist{\@authorlist\ifnum\@authorcount>1 , \fi ##1}
        \xdef\@firstauthor{\@firstauthor\ifnum\@authorcount=1 ##1\fi}
        \xdef\@authors{\ifnum\@authorcount>3 \@firstauthor~et~al.\else \@authorlist\fi}
        \begin{center}%
            \if!##4!
                {\sf\small\bfseries ##1}\\
                {\footnotesize\itshape ##2}\\[-0.5mm]
            \else
                \global\advance\@footcount by 1%
                {\sf\small\bfseries ##1}\hskip1pt{}\symbolfootnote[\@footcount]{##4}\\
                {\footnotesize\itshape ##2}\\[-0.5mm]
            \fi
            \if!##3!\else
                {\footnotesize {\tt ##3}}
            \fi
        \end{center}
    }

    \newcommand{\keywords}[1]{
    \global\def\@keywords{##1.}
    }

    \newcommand{\msc}[2][2010]{
        \global\def\@msca{##2.}
        \global\def\@mscy{##1}
    }


    
    \renewenvironment{abstract}
    {
        \hrule height 0.25pt
        \vskip 5pt
        \noindent {\small\sf\bfseries{}Abstract}
        \vskip 3pt
        \parindent0pt\footnotesize
    }
    {
        \vskip 4pt
            \noindent\textit{\footnotesize \if*\@receivedate Received: \today\\\else Received: \@receivedate\\\fi}
            \if@draft\else
                \textit{\footnotesize \if*\@lastrevdate\else Revised: \@lastrevdate\\\fi}
                \textit{\footnotesize \if*\@acceptdate Accepted: 31 September 20xx\\\else Accepted: \@acceptdate\\\fi}
                % \if@online
                		\textit{\footnotesize \if*\@onlinedate Available online: 31 September 20xx\\\else Available online: \@onlinedate\\\fi}
                %\fi
                \textit{\footnotesize \if*\@communicated Communicated with Acta Editor.\else Communicated with \@communicated.\fi}
                \vskip2pt
            \fi
            \if*\@keywords
                \ClassWarning{aumbart}{Keywords are missing; use \protect\keywords{...} command before
                \protect\begin{abstract} to introduce them.}
                \else
                \noindent {\footnotesize \textsf{\textbf{Keywords}}~\@keywords}
                \vskip 1pt
            \fi
            \if*\@msca
                \ClassWarning{aumbart}{AMS subject classification is missing; use \protect\msc[<year>]{...} before
                \protect\begin{abstract} to set it.}
                \else
                \noindent {\footnotesize \textsf{\textbf{MSC(\@mscy)}}~\@msca}
               \fi
        \vskip5pt
        \hrule height 0.25pt
        \global\@hasabstracttrue
    }
}
{
    \let\title\undefined
    \let\author\undefined
    \if@hasabstract\else
        \if@noabstract
            \hrule height 0.25pt
            \vskip 5pt
            \noindent\textit{\footnotesize \if*\@receivedate Received: 31 September 20xx\\\else Received: \@receivedate\\\fi}
            \if@draft\else
                \textit{\footnotesize \if*\@lastrevdate\else Revised: \@lastrevdate\\\fi}
                \textit{\footnotesize \if*\@acceptdate Accepted: 31 September 20xx\\\else Accepted: \@acceptdate\\\fi}
                \if@online
                		\textit{\footnotesize \if*\@onlinedate Available online: 31 September 20xx\\\else Available online \@onlinedatedate\\\fi}
                \fi
                \textit{\footnotesize \if*\@communicated Communicated with Acta Editor.\else Communicated with \@communicated.\fi}

                \vskip2pt
            \fi
            \if*\@keywords\else
                \noindent {\footnotesize \textsf{\textbf{Keywords:}}~\@keywords}
                \vskip 1pt
            \fi
            \if*\@msca\else
                \noindent {\footnotesize \textsf{\textbf{MSC~(\@mscy):}}~\@msca}
            \fi
            \vskip5pt
            \hrule height 0.25pt
        \else\ClassError{aumbart}{No abstract provided!}\fi
    \fi
        \vskip10pt~\normalsize
}

% page style setup
\if@draft    
        \newcommand{\ps@ap}{%
        \renewcommand\@oddhead{\hfil \small \textit{\@oddrunninghead} \hfil \textit{\thepage}}
        \renewcommand\@evenhead{\small \textit{\thepage} \hfil \textit{\@evenrunninghead} \hfil}
        \renewcommand\@evenfoot{}
        \renewcommand\@oddfoot{}
    }
    \newcommand{\ps@aptitle}{%
        \renewcommand\@oddhead{}
        \let\@evenhead\@oddhead
        \renewcommand\@evenfoot{}
        \let\@oddfoot\@evenfoot
    }
\else
    \newcommand{\ps@ap}{%
        \renewcommand\@oddhead{\hfil \small \textit{\@oddrunninghead} \hfil \textit{\thepage}}
        \renewcommand\@evenhead{\small \textit{\thepage} \hfil \textit{\@evenrunninghead} \hfil}
        \renewcommand\@evenfoot{}
        \renewcommand\@oddfoot{}
    }
    \newcommand{\ps@aptitle}{%
        \renewcommand\@oddhead{}
        \let\@evenhead\@oddhead
        \renewcommand\@evenfoot{\hfill\scriptsize Copyright \copyright{} \@journalyear{} Matej Bel University}
        \let\@oddfoot\@evenfoot
    }
\fi

% sectioning
\renewcommand{\section}{%
\@startsection{section}{1}{0pt}{-0.5\baselineskip}{0.5\baselineskip}{\sf\bfseries\normalsize}%
}

\renewcommand{\subsection}{%
\@startsection{subsection}{2}{0pt}{-0.5\baselineskip}{0.1\baselineskip}{\sf\bfseries}%
}

\renewcommand{\subsubsection}{%
\@startsection{subsubsection}{3}{0pt}{-0.5\baselineskip}{0.1\baselineskip}{\it}%
}

%claims
\theoremstyle{plain}
\newtheorem{theorem}{Theorem}
\newtheorem{proposition}[theorem]{Proposition}
\newtheorem{lemma}[theorem]{Lemma}
\newtheorem{corollary}[theorem]{Corollary}
\newtheorem{conjecture}[theorem]{Conjecture}
\newtheorem{problem}{Problem}
\theoremstyle{definition}
\newtheorem{definition}[theorem]{Definition}
\newtheorem{axiom}[theorem]{Axiom}
\newtheorem{example}[theorem]{Example}
\newtheorem{remark}[theorem]{Remark}
\newtheorem{question}[theorem]{Question}
\newtheorem{algorithm}[theorem]{Algorithm}
\newtheorem{construction}[theorem]{Construction}

% bibliography
\renewenvironment{thebibliography}[1]
     {\section*{\refname}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}
            \itemsep=0.0pt}%
      \sloppy
      \small
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}
\let\@openbib@code\@empty

% useful commands
\newcommand{\noabstract}{\@noabstracttrue}
\newcommand{\enquote}[1]{``#1''}

\def\enumerate{%
%  \setlength{\parsep}{0pt}
  \ifnum \@enumdepth >\thr@@\@toodeep\else
    \advance\@enumdepth\@ne
    \edef\@enumctr{enum\romannumeral\the\@enumdepth}%
      \expandafter
      \list
        \csname label\@enumctr\endcsname
        {\usecounter\@enumctr\def\makelabel##1{\hss\llap{##1}}%
          \itemsep=0pt}%
  \fi}
\def\itemize{%
%  \setlength{\parsep}{0pt}
  \ifnum \@itemdepth >\thr@@\@toodeep\else
    \advance\@itemdepth\@ne
    \edef\@itemitem{labelitem\romannumeral\the\@itemdepth}%
    \expandafter
    \list
      \csname\@itemitem\endcsname
      {\def\makelabel##1{\hss\llap{##1}}%
        \itemsep=0pt}%
  \fi}

% final setup
\pagestyle{ap}
\if@draft
    \if@linenum\setpagewiselinenumbers\linenumbers\fi
\else
\hypersetup{pdftitle={\p@pertitle}}
\hypersetup{pdfkeywords={\@keywords}}
\hypersetup{pdfauthor={\@authorlist}}
\fi

\RequirePackage[font=small]{caption}
\captionsetup{labelsep = period}
\RequirePackage{enumerate}
